## Version 0.2.0

- Improved documentation
- Removed all global state, all related PTs belong to a particular SoyutNet instance
- Arcs can have multiple labels
- Token count records can be merged and sorted by time at the end of simulation
- Added Graphviz dot file generator
- New tests and examples

## Version 0.1.0

First version
